@@ -1,18 +1,9 @@
-#![allow(unused_imports)]
-
-use {
-    git2::{RepositoryInitOptions, Time},
-    std::time::{SystemTime, UNIX_EPOCH},
-    ::{
-        clap::Parser,
-        eyre::{bail, ensure, eyre, Result as Fallible, WrapErr},
-        git2::{Commit, ErrorCode as GitErrorCode, Repository, Signature},
-        std::{
-            env, fs,
-            process::{exit, Command},
-        },
-        tracing::{debug, error, info, log, trace, warn},
-    },
+use ::{
+    clap::Parser,
+    eyre::{bail, ensure, Result as Fallible},
+    git2::{ErrorCode, Repository, RepositoryInitOptions, Signature, Time},
+    std::{env, fs, process::Command},
+    tracing::{debug, info, trace, warn},
 };
 
 /// Would you like to SAVE the change?
@@ -177,7 +168,7 @@ fn main() -> Fallible<()> {
 
     let head = match repo.head() {
         Ok(head) => Some(head.peel_to_commit().unwrap()),
-        Err(err) if err.code() == GitErrorCode::UnbornBranch => None,
+        Err(err) if err.code() == ErrorCode::UnbornBranch => None,
         Err(err) => {
             bail!("Unexpected error from Git: {:#?}", err);
         },
